@@ -157,11 +157,11 @@ class dyagram:
                     self.log.info(f"Pulled device {device} from Queue")
                     self.topology['devices'].append({'hostname': "", 'inventory_ip': device, 'layer2': {}, 'routes': [], 'dynamic_routing_neighbors': {}})
 
-                    executor.submit(self.__discover_lldp_neighbors, device)
+                    future_lldp = executor.submit(self.__discover_lldp_neighbors, device)
                     self.log.info(f"DEVICE: {device} - Submitted for discover_lldp_neighbors")
-                    executor.submit(self.discover_routes, device)
+                    future_routes = executor.submit(self.discover_routes, device)
                     self.log.info(f"DEVICE: {device} - Submitted for discover_routes")
-                    executor.submit(self.discover_dynamic_routing_neighbors, device)
+                    future_routing_neighbors = executor.submit(self.discover_dynamic_routing_neighbors, device)
                     self.log.info(f"DEVICE: {device} - Submitted for discover_dynamic_routing_neighbors")
 
                     self._devices_queried.append(device)
@@ -172,10 +172,10 @@ class dyagram:
                 except Exception:
                     tb = self.get_traceback()
                     self.log.info(f"EXCEPTION THROWN IN PULLING FROM QUEUE: {tb}")
-
-
+            time.sleep(25)
+            print("BEFORE SHUT")
             executor.shutdown(wait=True)
-
+            print("AFTER SHUT")
             #sort topology by hostname to compare to previous
 
             self.topology['devices'] = sorted(self.topology['devices'], key=lambda d: d['hostname'])
@@ -419,19 +419,26 @@ class dyagram:
     def discover_eigrp_neighbors_ssh(self, device):
 
         try:
+            self.log.info("GETTING DEVICE TYPE")
             os = self.get_device_type(device)
             if os:
+                self.log.info("GOT DEVICE TYPE")
                 nm_args = self.netmiko_args_template.copy()
                 nm_args['host'] = device
                 nm_args['device_type'] = os
                 print(f"NETMIKO ARGS FROM COPY TEMPLATE: {nm_args}")
 
             else:
-                raise Exception("Unable to determine OS.")
-
+                os = "cisco_ios"
+                #raise Exception("Unable to determine OS.")
+            self.log.info("GOT DEVICE TYPE")
 
+            print("BEFORE SETTING CH")
             dev = ConnectHandler(**nm_args)
+            print("AFTER SETTING CH")
             dev.enable()
+            print("AFTER SETTING ENABLE")
+
             if os in ['cisco_ios', 'cisco_nxos', 'cisco_xr']:
                 eigrp_output = dev.send_command("show ip eigrp neighbors vrf all") #textfsm not currently supported for this command
                 if isinstance(eigrp_output, str):
@@ -446,6 +453,7 @@ class dyagram:
                 raise Exception(f"OS {os} Not supported")
             dev.disconnect()
         except:
+            self.log.info("HIT EXCEPT discover_eigrp_neighbors_ssh")
             tb = self.get_traceback()
             self.log.info(f"DEVICE: {device} - SSH : discover_eigrp_neighbors_ssh - {tb}")
 
